// WWVB Clock Receiver

/*

Compiler Version:
    Arduino     1.8.19
    Teensyduino 1.57

Compiler Options:

    Board:      Teensy 4.0
    USB Type:   Serial
    CPU Speed:  600MHz

    also

    Board:      Teensy 3.2
    USB Type:   Serial
    CPU Speed:  72 MHz

*/

#pragma GCC diagnostic ignored "-Wwrite-strings"            // always ignore warning about using strings as constants
//#pragma GCC diagnostic ignored "-Wunused-variable"          // ignore unused variables until near end of development cycle, then comment this

#include                <Arduino.h>
#include                "globals.h"

// The MCU type should be automatically set in globals.h. Report the setting:
#if defined mcuTeensy4x
    #pragma message "Compiling for Teensy 4x"
#elif defined mcuTeensy3x
    #pragma message "Compiling for Teensy 3x"
#elif defined mcuNano
    #pragma error   "UNKNOWN MCU"
#endif

// Report the RTC type to be used. This is manually set in globals.h
#if defined rtcTeensy
    #pragma message "Compiling for Teensy internal RTC"
#elif defined rtcDS3231
    #pragma message "Compiling for DS3231 external RTC"
#else
    #pragma message "Compiling for NO RTC"
#endif

// ============================================================================

void setup(
    ) {

Serial.begin(9600);

pinMode(pin_radioIn,            INPUT);

} // setup

//-----------------------------------------------------------------------------
// Implement as state machine

void loop(
    ) {

enum {                                                      // machine state codes
                        st_init         = 0,                // initization state
                        st_idle_init    = 1,                // initialize idle state
                        st_idle         = 2,                // waiting for something to happen
                        st_sigStrength  = 3,                // show continuously updating Time/Temp
                        };

bool                    printOK         = true;
char                    s[80];                              // multi-purpose string buffer
byte                    state           = st_init;          // state machine's current state

debugMode = true;                                           // enable debugging output

if (debugMode)
    serdb.println("@loop");

state = st_init;                                            // set the initial state for the state machine

while (true) {                                              // state machine infinite loop

    switch(state) {                                         // execute the current state

        //.............................................................................
        // *** init
        // This state is called one time at the start of the program.

        case st_init:

            if (debugMode)
                serdb.println("@STATE: st_init");

            ti_init(3, true);                               // initialize the RTC

            wwv_init(0, 0);                                 // sync time to wwvb. Start at midnight, try for 6 hours

            state = st_idle_init;                           // set the next state

            if (debugMode)
                serdb.printf("Press any key to monitor signal strength.\n");

            break; // case init

        //.............................................................................
        // *** idle_init
        // This state is called at the beginning of each idle state. Only this state should
        // call the actual idle state.

        // I used idle_init to display that we have entered the idle state because we
        // don't want to display text everytime the idle state starts.

        case st_idle_init:

            if (debugMode)
                serdb.println("@STATE: st_idle_init");

            state = st_idle;

            break; // case idle_init

        //.............................................................................
        // *** idle
        // Idle state is the "Main loop". It waits for an event to occur then selects
        // the appropriate next state.

        case st_idle:

            ti_updDLS();                                    // check to see if we need to fix DLS time

            if (serdb.available()) {
                while (serdb.available())
                    serdb.read();
                state = st_sigStrength;
                break;
                }

            if (now() % 60UL == 0) {
                if (printOK) {
                    serdb.printf("Date & Time: %s: ti_valid: %d\n",
                        ti_getDateTime(s, sizeof(s)), ti_valid);
                    printOK = false;
                    }
            }
            else
                printOK = true;

            break; // case idle

        //.............................................................................
        // *** st_sigStrength
        // displays the current signal strength until user presses a key. Note that
        // this will stop all other processing as it never leaves this state.

        case st_sigStrength:

            if (debugMode)
                serdb.println("@STATE: st_sigStrength");
            if (debugMode)
                serdb.printf("Press any key to stop monitoring signal strength.\n");
            while (true) {
                if (serdb.available()) {
                    while (serdb.available())
                        serdb.read();
                    if (debugMode)
                        serdb.printf("\nDone Monitoring.\n");
                    state = st_idle_init;
                    break;
                    }
                snprintf(s, sizeof(s),
                    "%d", wwv_sigStrength());
                delay(200);

                } // while


            state = st_idle_init;                           // return to idle

            break; // case st_timeTemp

        //.............................................................................
        // *** unknown state, simply return to idle (should never get here)

        default:

            if (debugMode)
                serdb.println("@STATE: default!!!");

            state = st_idle_init;
            break;

        } // switch

    } // infinite while

} // loop
