// ----------------------------------------------------------------------------
// globally accessible procedures

#pragma GCC diagnostic ignored "-Wwrite-strings"            // always ignore warning about using strings as constants
#pragma GCC diagnostic ignored "-Wunused-variable"          // ignore unused variables until near end of development cycle, then comment this

#include                <Arduino.h>

#include                "globals.h"

#include                "time.h"                            // for dateTime2timeStamp

// ---------------------------------------------------------------------------
// Public Globals
// external's in h file defined here
// ---------------------------------------------------------------------------

bool                    debugMode       = true;

// ----------------------------------------------------------------------------
// Private Constants
// ----------------------------------------------------------------------------

// ---------------------------------------------------------------------------
// Private Globals
// ---------------------------------------------------------------------------

// ---------------------------------------------------------------------------
// Private Forward declarations

// ============================================================================

// ----------------------------------------------------------------------------
// Convert m/d/y h:m:s to unix timestamp

time_t dateTime2timeStamp(
    int                 year,                               // 1900-
    int                 month,                              // 1-12
    int                 day,                                // 1-31
    int                 hour,                               // 0-23
    int                 minute,                             // 0-59
    int                 second                              // 0-59
    ) {

tm                      dateTime;

dateTime.tm_sec         = second;
dateTime.tm_min         = minute;
dateTime.tm_hour        = hour;
dateTime.tm_mday        = day;
dateTime.tm_mon         = month - 1;
dateTime.tm_year        = year - 1900;

return mktime(&dateTime);

} // dateTime2timeStamp

// ----------------------------------------------------------------------------
// Function to convert day of the year to normal date

void dayOfYearToDate(
    int                 year,
    int                 dayOfYear,
    int                 *month,
    int                 *day
    ) {

int                     daysInMonth[]   = {0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
int                     monthIndex      = 1;

if ((year % 4 == 0 && year % 100 != 0) || (year % 400 == 0)) {
    // Leap year, so February has 29 days
    daysInMonth[2] = 29;
    }

while (dayOfYear > daysInMonth[monthIndex]) {
    dayOfYear = dayOfYear - daysInMonth[monthIndex];
    monthIndex = monthIndex + 1;
    } // while

*month = monthIndex;
*day = dayOfYear;

} // dayOfYearToDate

// ----------------------------------------------------------------------------
// return true if S contains only digits

int isNumeric (
    const char *        s
    ) {

char *                  p;

if (s == NULL || *s == '\0' || isspace(*s))
    return 0;

strtod (s, &p);
return *p == '\0';

} // isNumeric

// ----------------------------------------------------------------------------
// Tests timer. Returns true if it has popped

bool timerPop(
    ulong           timer,
    ulong           timeout
    ) {

if (timer == 0UL)                       // handle initialization
    return true;
else if (millis() - timer > timeout)
    return true;
else
    return false;

} // timerPop
