//----------------------------------------------------------------------------
// global definitions for block heater sensor

#ifndef globals_h
#define globals_h

// Compiler Options to specify MCU type and RTC type

// Define mcu<xxxx> macro based on the type of MCU. This is computed
// automatically from externally set macro names.

// For Teensy3x and 4x, the only differences in the code are the
// assignment of the radioIn signal pin.

#ifdef __IMXRT1062__
#define                 mcuTeensy4x
#endif // __IMXRT1062__

#ifdef KINETISK
#define                 mcuTeensy3x
#endif

// Define type of real time clock being used. Manually select the
// appropriate clock by uncommenting appropriate Macro name.

#define                 rtcTeensy                           // RTC internal to Teensy 3x/4x
//#define                 rtcDS3231                           // External DS3231 RTC
//#define                 rtcNone                             // No RTC available

#include                <Arduino.h>

#include                "mytimelib.h"
#include                "wwvblib.h"

// ----------------------------------------------------------------------------
// Global Defines
// ----------------------------------------------------------------------------

// Alternate names for Serial, Serial1, Serial2

#define                 serdb           Serial              // The debug serial port

// ----------------------------------------------------------------------------
// Global Enumerations
// ----------------------------------------------------------------------------

// ----------------------------------------------------------------------------
// Global Constants
// ----------------------------------------------------------------------------

// Teensy Pins Used (listed by pin)

#ifdef mcuTeensy4x
    const int           pin_radioIn     =  3;               // connected to OUT pin on the WWVB Breakout board
#endif
#ifdef mcuTeensy3x
    const int           pin_radioIn     =  20;              // connected to OUT pin on the WWVB Breakout board
#endif

// ----------------------------------------------------------------------------
// Global types
// ----------------------------------------------------------------------------

typedef
    unsigned long       ulong;                              // unsigned long doesn't always fit in alloted space

// ----------------------------------------------------------------------------
// Global Variables
// ----------------------------------------------------------------------------

extern bool             debugMode;

// ----------------------------------------------------------------------------
// Global Forwards
// ----------------------------------------------------------------------------

// t=dateTime2timeStamp(..) convert y,m,d,h,m,s to timeStamp
// dayOfYearToDate(...)     Convert day of year to month/day
// b=isNumeric(s)           is string numeric?
// b=timerPop(tmr,timeout)  returns true if timer has popped

time_t dateTime2timeStamp(
    int                 year,                               // 1900-
    int                 month,                              // 1-12
    int                 day,                                // 1-31
    int                 hour,                               // 0-23
    int                 minute,                             // 0-59
    int                 second                              // 0-59
    );

void dayOfYearToDate(
    int                 year,
    int                 dayOfYear,
    int                 *month,
    int                 *day
    );

int isNumeric (
    const char *    s
    );

bool timerPop(
    ulong           timer,
    ulong           timeout
    );

#endif // globals_h

