//----------------------------------------------------------------------------
// time functions

#ifndef mytimelib_h
#define mytimelib_h

#include                <Arduino.h>
#include                "globals.h"

#include                "Timezone.h"

// ----------------------------------------------------------------------------
// Global Constants
// ----------------------------------------------------------------------------

const int               ti_zonesMax     = 4;
extern const char       *ti_zones[ti_zonesMax];             // TZ names corr to eeprom.tz 0-3

// ----------------------------------------------------------------------------
// Global types
// ----------------------------------------------------------------------------

// ----------------------------------------------------------------------------
// Global Variables
// ----------------------------------------------------------------------------

extern time_t           ti_bootTime;                        // time system was booted
extern bool             ti_DLS;                             // are we currently observing DLS time?
extern bool             ti_valid;                           // true if RTC is working

// ----------------------------------------------------------------------------
// Global Forwards
// ----------------------------------------------------------------------------

// s=ti_getDateTime(s,m)returns date/time as mm/dd/yy hh:mm:ss
// s=ti_getTime(s, max) return time as hh:mm xM
// s=ti_getTZ(s, max)   return TZ name of eeprom.tz
// ti_init(tz, useDLS)  Initialize time module. Do we observe DLS Time?
// ti_newTZ(tz)         Change TZ, adjust clock accordingly
// t=ti_setRTC(t)       Given t in GMT, sets RTC to local time. Returns local time
// ti_updDLS()          If DLS has changed, adjust clock appropriately

char * ti_getDateTime(
    char *              s,
    int                 maxlen
    );

char * ti_getTime(
    char *              s,
    int                 maxlen
    );

char * ti_getTZ(
    char *              s,
    int                 smax
    );

void ti_init(
    int                 tz,                                 // timezone we are in 0-3: EST, CST, MST, PST
    bool                useDLSp         = true
    );

void ti_newTZ(
    int                 tz                                  // timezone to change to, 0-3: EST, CST, MST, PST
    );

void ti_reinit(                                             // used when NOT ti_valid and now we have a good time
    );

time_t ti_setRTC(
    time_t              timeStamp
    );

void ti_updDLS(
    );

#endif // mytimelib_h

