//----------------------------------------------------------------------------
// time functions

#ifndef wwvblib_h
#define wwvblib_h

#include                <Arduino.h>
#include                "globals.h"

// ----------------------------------------------------------------------------
// Global types
// ----------------------------------------------------------------------------

struct                  wwv_decode_t {                      // contents of decoded packet
    uint16_t            minutes;
    uint16_t            hours;
    uint16_t            dayOfYear;
    uint16_t            dut1OffsetSign;
    float               dut1OffsetValue;
    uint16_t            year;
    uint16_t            leapYear;
    uint16_t            leapSecond;
    uint16_t            dstIndicator;
    };

enum                    wwv_state_t {                       // state of the wwv module
    wwv_invalid,                                            // wwvb has not rx'ed a valid time
    wwv_listening,                                          // in process of getting wwvb time
    wwv_valid                                               // wwvb time rxed and RTC set?
    };

// ----------------------------------------------------------------------------
// Global Variables
// ----------------------------------------------------------------------------

extern volatile uint16_t
                        wwv_abortCount;                     // number of time wwv has given up trying to find valid packet as duration exceeded
extern volatile wwv_decode_t
                        wwv_decode;                         // the decoded wwvb packet. Values are defined when wwv_state is wwv_valid
extern volatile float   wwv_corrAvg;                        // # Average correction in seconds (real)
extern volatile int     wwv_corrLast;                       // # of seconds the clock was last corrected
extern volatile int
                        wwv_corrTotal;                      // Total number of corrections made
extern volatile time_t  wwv_timeSet;                        // time RTC was last set by wwvb. 0 means never set.
extern volatile wwv_state_t
                        wwv_state;                          // wwv module state
extern volatile uint16_t
                        wwv_syncCount;                      // # of times RTC clock has been sync'ed to WWVB

// ----------------------------------------------------------------------------
// Global Forwards
// ----------------------------------------------------------------------------

// wwv_end()            stop wwvb module
// wwv_init(start,dur)  initialize wwvb module.
// i=wwv_sigStrength    Return signal strength 0-10 where 10 is best signal (BLOCKING)

void wwv_end(
    );

void wwv_init(
    int                 startHour       = 0,                // starting hour
    int                 duration        = 6                 // duration in hours
    );

// Note: this functino takes 3 seconds to run during which nothing else runs!!!

int wwv_sigStrength(
    );

#endif // wwvblib_h
